@@ -407,9 +407,9 @@ def get_sample_assembly_and_reads(sample_ids):
     assemblies = db.sample_components.find({
         "sample._id": {"$in": sample_ids},
         "component.name": "assemblatron"
-    }, {"path": 1})
+    }, {"path": 1, "sample._id": 1})
     for a in assemblies:
-        samples[str(a["_id"])] = {"assembly": a["path"] + "/contigs.fasta"}
+        samples[str(a["sample"]["_id"])] = {"assembly": a["path"] + "/contigs.fasta"}
 
     reads = list(db.samples.find({"_id": {"$in": sample_ids}}, {"reads": 1}))
     for r in reads:
